@@ -1,11 +1,11 @@
 //! I/O helper structs for age file encryption and decryption.
 
+use age_core::secrecy::{ExposeSecret, SecretVec};
 use chacha20poly1305::{
     aead::{generic_array::GenericArray, Aead, NewAead},
-    ChaChaPoly1305,
+    ChaCha20Poly1305,
 };
 use pin_project::pin_project;
-use secrecy::{ExposeSecret, SecretVec};
 use std::cmp;
 use std::convert::TryInto;
 use std::io::{self, Read, Seek, SeekFrom, Write};
@@ -24,9 +24,7 @@ const CHUNK_SIZE: usize = 64 * 1024;
 const TAG_SIZE: usize = 16;
 const ENCRYPTED_CHUNK_SIZE: usize = CHUNK_SIZE + TAG_SIZE;
 
-pub(crate) struct PayloadKey(
-    pub(crate) GenericArray<u8, <ChaChaPoly1305<c2_chacha::Ietf> as NewAead>::KeySize>,
-);
+pub(crate) struct PayloadKey(pub(crate) GenericArray<u8, <ChaCha20Poly1305 as NewAead>::KeySize>);
 
 impl Drop for PayloadKey {
     fn drop(&mut self) {
@@ -76,6 +74,7 @@ impl Nonce {
 }
 
 #[cfg(feature = "async")]
+#[cfg_attr(docsrs, doc(cfg(feature = "async")))]
 struct EncryptedChunk {
     bytes: Vec<u8>,
     offset: usize,
@@ -89,14 +88,14 @@ struct EncryptedChunk {
 ///
 /// [STREAM]: https://eprint.iacr.org/2015/189.pdf
 pub(crate) struct Stream {
-    aead: ChaChaPoly1305<c2_chacha::Ietf>,
+    aead: ChaCha20Poly1305,
     nonce: Nonce,
 }
 
 impl Stream {
     fn new(key: PayloadKey) -> Self {
         Stream {
-            aead: ChaChaPoly1305::new(&key.0),
+            aead: ChaCha20Poly1305::new(&key.0),
             nonce: Nonce::default(),
         }
     }
@@ -126,6 +125,7 @@ impl Stream {
     ///
     /// [`HKDF`]: age_core::primitives::hkdf
     #[cfg(feature = "async")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "async")))]
     pub(crate) fn encrypt_async<W: AsyncWrite>(key: PayloadKey, inner: W) -> StreamWriter<W> {
         StreamWriter {
             stream: Self::new(key),
@@ -163,6 +163,7 @@ impl Stream {
     ///
     /// [`HKDF`]: age_core::primitives::hkdf
     #[cfg(feature = "async")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "async")))]
     pub(crate) fn decrypt_async<R: AsyncRead>(key: PayloadKey, inner: R) -> StreamReader<R> {
         StreamReader {
             stream: Self::new(key),
@@ -225,6 +226,7 @@ pub struct StreamWriter<W> {
     inner: W,
     chunk: Vec<u8>,
     #[cfg(feature = "async")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "async")))]
     encrypted_chunk: Option<EncryptedChunk>,
 }
 
@@ -272,6 +274,7 @@ impl<W: Write> Write for StreamWriter<W> {
 }
 
 #[cfg(feature = "async")]
+#[cfg_attr(docsrs, doc(cfg(feature = "async")))]
 impl<W: AsyncWrite> StreamWriter<W> {
     fn poll_flush_chunk(self: Pin<&mut Self>, cx: &mut Context) -> Poll<io::Result<()>> {
         let StreamWriterProj {
@@ -296,6 +299,7 @@ impl<W: AsyncWrite> StreamWriter<W> {
 }
 
 #[cfg(feature = "async")]
+#[cfg_attr(docsrs, doc(cfg(feature = "async")))]
 impl<W: AsyncWrite> AsyncWrite for StreamWriter<W> {
     fn poll_write(
         mut self: Pin<&mut Self>,
@@ -467,6 +471,7 @@ impl<R: Read> Read for StreamReader<R> {
 }
 
 #[cfg(feature = "async")]
+#[cfg_attr(docsrs, doc(cfg(feature = "async")))]
 impl<R: AsyncRead + Unpin> AsyncRead for StreamReader<R> {
     fn poll_read(
         mut self: Pin<&mut Self>,
@@ -638,7 +643,7 @@ impl<R: Read + Seek> Seek for StreamReader<R> {
 
 #[cfg(test)]
 mod tests {
-    use secrecy::ExposeSecret;
+    use age_core::secrecy::ExposeSecret;
     use std::io::{self, Cursor, Read, Seek, SeekFrom, Write};
 
     use super::{PayloadKey, Stream, CHUNK_SIZE};
