@@ -7,10 +7,9 @@
 //! Note that these recipient types are not anonymous: the encrypted message will include
 //! a short 32-bit ID of the public key.
 
-use aes::Aes256;
-use aes_ctr::{Aes128Ctr, Aes192Ctr, Aes256Ctr};
+use aes::{Aes128Ctr, Aes192Ctr, Aes256, Aes256Ctr};
+use age_core::secrecy::{ExposeSecret, SecretString};
 use bcrypt_pbkdf::bcrypt_pbkdf;
-use secrecy::{ExposeSecret, SecretString};
 use sha2::{Digest, Sha256};
 
 use crate::error::DecryptError;
@@ -111,15 +110,16 @@ impl EncryptedKey {
 }
 
 mod decrypt {
-    use aes::cipher::block::{BlockCipher, NewBlockCipher};
-    use aes_ctr::cipher::stream::{NewStreamCipher, StreamCipher};
+    use aes::cipher::{
+        BlockCipher, BlockDecrypt, BlockEncrypt, NewBlockCipher, NewCipher, StreamCipher,
+    };
+    use age_core::secrecy::SecretString;
     use block_modes::{block_padding::NoPadding, BlockMode, Cbc};
-    use secrecy::SecretString;
 
     use super::OpenSshKdf;
     use crate::error::DecryptError;
 
-    pub(super) fn aes_cbc<C: BlockCipher + NewBlockCipher>(
+    pub(super) fn aes_cbc<C: BlockCipher + BlockEncrypt + BlockDecrypt + NewBlockCipher>(
         kdf: &OpenSshKdf,
         passphrase: SecretString,
         ciphertext: &[u8],
@@ -128,13 +128,14 @@ mod decrypt {
         let kdf_output = kdf.derive(passphrase, key_len + 16);
         let (key, iv) = kdf_output.split_at(key_len);
 
-        let cipher = Cbc::<C, NoPadding>::new_var(key, iv).expect("key and IV are correct length");
+        let cipher =
+            Cbc::<C, NoPadding>::new_from_slices(key, iv).expect("key and IV are correct length");
         cipher
             .decrypt_vec(&ciphertext)
             .map_err(|_| DecryptError::KeyDecryptionFailed)
     }
 
-    pub(super) fn aes_ctr<C: NewStreamCipher + StreamCipher>(
+    pub(super) fn aes_ctr<C: NewCipher + StreamCipher>(
         kdf: &OpenSshKdf,
         passphrase: SecretString,
         ciphertext: &[u8],
@@ -143,10 +144,10 @@ mod decrypt {
         let kdf_output = kdf.derive(passphrase, key_len + 16);
         let (key, nonce) = kdf_output.split_at(key_len);
 
-        let mut cipher = C::new_var(key, nonce).expect("key and nonce are correct length");
+        let mut cipher = C::new_from_slices(key, nonce).expect("key and nonce are correct length");
 
         let mut plaintext = ciphertext.to_vec();
-        cipher.decrypt(&mut plaintext);
+        cipher.apply_keystream(&mut plaintext);
         plaintext
     }
 }
@@ -244,7 +245,7 @@ mod read_asn1 {
     ///
     /// We only support the two-prime encoding, where `version = 0` and `otherPrimeInfos`
     /// is omitted.
-    pub(super) fn rsa_privkey(input: &[u8]) -> IResult<&[u8], rsa::RSAPrivateKey> {
+    pub(super) fn rsa_privkey(input: &[u8]) -> IResult<&[u8], rsa::RsaPrivateKey> {
         preceded(
             // Type: Universal | Constructed | SEQUENCE
             der_type(0, 1, 16),
@@ -256,7 +257,7 @@ mod read_asn1 {
                         map(
                             tuple((integer, integer, integer, integer, integer)),
                             |(n, e, d, p, q)| {
-                                rsa::RSAPrivateKey::from_components(n, e, d, vec![p, q])
+                                rsa::RsaPrivateKey::from_components(n, e, d, vec![p, q])
                             },
                         ),
                         // d mod (p-1), d mod (q-1), iqmp
@@ -269,6 +270,7 @@ mod read_asn1 {
 }
 
 mod read_ssh {
+    use age_core::secrecy::Secret;
     use curve25519_dalek::edwards::{CompressedEdwardsY, EdwardsPoint};
     use nom::{
         branch::alt,
@@ -281,7 +283,6 @@ mod read_ssh {
     };
     use num_traits::Zero;
     use rsa::BigUint;
-    use secrecy::Secret;
 
     use super::{
         identity::{UnencryptedKey, UnsupportedKey},
@@ -395,12 +396,12 @@ mod read_ssh {
     /// Internal OpenSSH encoding of an RSA private key.
     ///
     /// - [OpenSSH serialization code](https://github.com/openssh/openssh-portable/blob/4103a3ec7c68493dbc4f0994a229507e943a86d3/sshkey.c#L3187-L3198)
-    fn openssh_rsa_privkey(input: &[u8]) -> IResult<&[u8], rsa::RSAPrivateKey> {
+    fn openssh_rsa_privkey(input: &[u8]) -> IResult<&[u8], rsa::RsaPrivateKey> {
         preceded(
             string_tag(SSH_RSA_KEY_PREFIX),
             map(
                 tuple((mpint, mpint, mpint, mpint, mpint, mpint)),
-                |(n, e, d, _iqmp, p, q)| rsa::RSAPrivateKey::from_components(n, e, d, vec![p, q]),
+                |(n, e, d, _iqmp, p, q)| rsa::RsaPrivateKey::from_components(n, e, d, vec![p, q]),
             ),
         )(input)
     }
@@ -533,11 +534,11 @@ mod read_ssh {
     /// mpint     e
     /// mpint     n
     /// ```
-    pub(super) fn rsa_pubkey(input: &[u8]) -> IResult<&[u8], rsa::RSAPublicKey> {
+    pub(super) fn rsa_pubkey(input: &[u8]) -> IResult<&[u8], rsa::RsaPublicKey> {
         preceded(
             string_tag(SSH_RSA_KEY_PREFIX),
             map_res(tuple((mpint, mpint)), |(exponent, modulus)| {
-                rsa::RSAPublicKey::new(modulus, exponent)
+                rsa::RsaPublicKey::new(modulus, exponent)
             }),
         )(input)
     }
@@ -603,7 +604,7 @@ mod write_ssh {
     /// mpint     e
     /// mpint     n
     /// ```
-    pub(super) fn rsa_pubkey<W: Write>(pubkey: &rsa::RSAPublicKey) -> impl SerializeFn<W> {
+    pub(super) fn rsa_pubkey<W: Write>(pubkey: &rsa::RsaPublicKey) -> impl SerializeFn<W> {
         tuple((
             string(SSH_RSA_KEY_PREFIX),
             mpint(pubkey.e()),
